@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2010-2011 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -78,20 +78,26 @@ G_DEFINE_TYPE (GcmSensorHuey, gcm_sensor_huey, GCM_TYPE_SENSOR)
 /* fudge factor to convert the value of GCM_SENSOR_HUEY_COMMAND_GET_AMBIENT to Lux */
 #define HUEY_AMBIENT_UNITS_TO_LUX	125.0f
 
-/* this is the same approx ratio as argyll uses to find the best accuracy
- * whilst maintaining a fast read. We scale each RGB value seporately. */
-#define HUEY_PRECISION_TIME_VALUE		3500
+/* The CY7C63001 is paired with a 6.00Mhz crystal */
+#define HUEY_CLOCK_FREQUENCY		6e6
+
+/* It takes 6 clock pulses to process a single 16bit increment (INC)
+ * instruction and check for the carry so this is the fastest a loop
+ * can be processed. */
+#define HUEY_POLL_FREQUENCY		1e6
 
 /* Picked out of thin air, just to try to match reality...
  * I have no idea why we need to do this, although it probably
  * indicates we doing something wrong. */
-#define HUEY_XYZ_POST_MULTIPLY_SCALE_FACTOR	3.347250f
+#define HUEY_XYZ_POST_MULTIPLY_SCALE_FACTOR	3.43
 
 /**
  * gcm_sensor_huey_print_data:
  **/
 static void
-gcm_sensor_huey_print_data (const gchar *title, const guchar *data, gsize length)
+gcm_sensor_huey_print_data (const gchar *title,
+			    const guchar *data,
+			    gsize length)
 {
 	guint i;
 
@@ -220,16 +226,30 @@ out:
  * gcm_sensor_huey_read_register_byte:
  **/
 static gboolean
-gcm_sensor_huey_read_register_byte (GcmSensorHuey *sensor_huey, guint8 addr, guint8 *value, GError **error)
+gcm_sensor_huey_read_register_byte (GcmSensorHuey *sensor_huey,
+				    guint8 addr,
+				    guint8 *value,
+				    GError **error)
 {
-	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_REGISTER_READ, 0xff, 0x00, 0x10, 0x3c, 0x06, 0x00, 0x00 };
+	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_REGISTER_READ,
+			     0xff,
+			     0x00,
+			     0x10,
+			     0x3c,
+			     0x06,
+			     0x00,
+			     0x00 };
 	guchar reply[8];
 	gboolean ret;
 	gsize reply_read;
 
 	/* hit hardware */
 	request[1] = addr;
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 error);
 	if (!ret)
 		goto out;
 	*value = reply[3];
@@ -241,14 +261,21 @@ out:
  * gcm_sensor_huey_read_register_string:
  **/
 static gboolean
-gcm_sensor_huey_read_register_string (GcmSensorHuey *huey, guint8 addr, gchar *value, gsize len, GError **error)
+gcm_sensor_huey_read_register_string (GcmSensorHuey *huey,
+				      guint8 addr,
+				      gchar *value,
+				      gsize len,
+				      GError **error)
 {
 	guint8 i;
 	gboolean ret = TRUE;
 
 	/* get each byte of the string */
 	for (i=0; i<len; i++) {
-		ret = gcm_sensor_huey_read_register_byte (huey, addr+i, (guint8*) &value[i], error);
+		ret = gcm_sensor_huey_read_register_byte (huey,
+							  addr+i,
+							  (guint8*) &value[i],
+							  error);
 		if (!ret)
 			goto out;
 	}
@@ -260,7 +287,10 @@ out:
  * gcm_sensor_huey_read_register_word:
  **/
 static gboolean
-gcm_sensor_huey_read_register_word (GcmSensorHuey *huey, guint8 addr, guint32 *value, GError **error)
+gcm_sensor_huey_read_register_word (GcmSensorHuey *huey,
+				    guint8 addr,
+				    guint32 *value,
+				    GError **error)
 {
 	guint8 i;
 	guint8 tmp[4];
@@ -268,7 +298,10 @@ gcm_sensor_huey_read_register_word (GcmSensorHuey *huey, guint8 addr, guint32 *v
 
 	/* get each byte of the 32 bit number */
 	for (i=0; i<4; i++) {
-		ret = gcm_sensor_huey_read_register_byte (huey, addr+i, tmp+i, error);
+		ret = gcm_sensor_huey_read_register_byte (huey,
+							  addr+i,
+							  tmp+i,
+							  error);
 		if (!ret)
 			goto out;
 	}
@@ -283,13 +316,19 @@ out:
  * gcm_sensor_huey_read_register_float:
  **/
 static gboolean
-gcm_sensor_huey_read_register_float (GcmSensorHuey *huey, guint8 addr, gfloat *value, GError **error)
+gcm_sensor_huey_read_register_float (GcmSensorHuey *huey,
+				     guint8 addr,
+				     gfloat *value,
+				     GError **error)
 {
 	gboolean ret;
 	guint32 tmp;
 
 	/* first read in 32 bit integer */
-	ret = gcm_sensor_huey_read_register_word (huey, addr, &tmp, error);
+	ret = gcm_sensor_huey_read_register_word (huey,
+						  addr,
+						  &tmp,
+						  error);
 	if (!ret)
 		goto out;
 
@@ -303,7 +342,10 @@ out:
  * gcm_sensor_huey_read_register_vector:
  **/
 static gboolean
-gcm_sensor_huey_read_register_vector (GcmSensorHuey *huey, guint8 addr, GcmVec3 *value, GError **error)
+gcm_sensor_huey_read_register_vector (GcmSensorHuey *huey,
+				      guint8 addr,
+				      GcmVec3 *value,
+				      GError **error)
 {
 	gboolean ret = TRUE;
 	guint i;
@@ -315,7 +357,10 @@ gcm_sensor_huey_read_register_vector (GcmSensorHuey *huey, guint8 addr, GcmVec3
 
 	/* read in vec3 */
 	for (i=0; i<3; i++) {
-		ret = gcm_sensor_huey_read_register_float (huey, addr + (i*4), &tmp, error);
+		ret = gcm_sensor_huey_read_register_float (huey,
+							   addr + (i*4),
+							   &tmp,
+							   error);
 		if (!ret)
 			goto out;
 
@@ -330,7 +375,10 @@ out:
  * gcm_sensor_huey_read_register_matrix:
  **/
 static gboolean
-gcm_sensor_huey_read_register_matrix (GcmSensorHuey *huey, guint8 addr, GcmMat3x3 *value, GError **error)
+gcm_sensor_huey_read_register_matrix (GcmSensorHuey *huey,
+				      guint8 addr,
+				      GcmMat3x3 *value,
+				      GError **error)
 {
 	gboolean ret = TRUE;
 	guint i;
@@ -342,7 +390,10 @@ gcm_sensor_huey_read_register_matrix (GcmSensorHuey *huey, guint8 addr, GcmMat3x
 
 	/* read in 3d matrix */
 	for (i=0; i<9; i++) {
-		ret = gcm_sensor_huey_read_register_float (huey, addr + (i*4), &tmp, error);
+		ret = gcm_sensor_huey_read_register_float (huey,
+							   addr + (i*4),
+							   &tmp,
+							   error);
 		if (!ret)
 			goto out;
 
@@ -358,7 +409,8 @@ out:
  * gcm_sensor_huey_get_ambient_state_finish:
  **/
 static void
-gcm_sensor_huey_get_ambient_state_finish (GcmSensorAsyncState *state, const GError *error)
+gcm_sensor_huey_get_ambient_state_finish (GcmSensorAsyncState *state,
+					  const GError *error)
 {
 	gdouble *result;
 
@@ -389,13 +441,16 @@ gcm_sensor_huey_get_ambient_state_finish (GcmSensorAsyncState *state, const GErr
  * gcm_sensor_huey_cancellable_cancel_cb:
  **/
 static void
-gcm_sensor_huey_cancellable_cancel_cb (GCancellable *cancellable, GcmSensorAsyncState *state)
+gcm_sensor_huey_cancellable_cancel_cb (GCancellable *cancellable,
+				       GcmSensorAsyncState *state)
 {
 	g_warning ("cancelled huey");
 }
 
 static void
-gcm_sensor_huey_get_ambient_thread_cb (GSimpleAsyncResult *res, GObject *object, GCancellable *cancellable)
+gcm_sensor_huey_get_ambient_thread_cb (GSimpleAsyncResult *res,
+				       GObject *object,
+				       GCancellable *cancellable)
 {
 	GcmSensor *sensor = GCM_SENSOR (object);
 	gdouble *result;
@@ -404,7 +459,14 @@ gcm_sensor_huey_get_ambient_thread_cb (GSimpleAsyncResult *res, GObject *object,
 	gboolean ret = FALSE;
 	gsize reply_read;
 	GcmSensorOutputType output_type;
-	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_GET_AMBIENT, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
+	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_GET_AMBIENT,
+			     0x03,
+			     0x00,
+			     0x00,
+			     0x00,
+			     0x00,
+			     0x00,
+			     0x00 };
 	GcmSensorHuey *sensor_huey = GCM_SENSOR_HUEY (sensor);
 
 	/* ensure sensor is started */
@@ -443,7 +505,11 @@ gcm_sensor_huey_get_ambient_thread_cb (GSimpleAsyncResult *res, GObject *object,
 
 	/* hit hardware */
 	request[2] = (output_type == GCM_SENSOR_OUTPUT_TYPE_LCD) ? 0x00 : 0x02;
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, &error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 &error);
 	if (!ret) {
 		g_simple_async_result_set_from_error (res, error);
 		g_error_free (error);
@@ -463,7 +529,9 @@ out:
  * gcm_sensor_huey_get_ambient_async:
  **/
 static void
-gcm_sensor_huey_get_ambient_async (GcmSensor *sensor, GCancellable *cancellable, GAsyncResult *res)
+gcm_sensor_huey_get_ambient_async (GcmSensor *sensor,
+				   GCancellable *cancellable,
+				   GAsyncResult *res)
 {
 	GcmSensorAsyncState *state;
 
@@ -487,7 +555,10 @@ gcm_sensor_huey_get_ambient_async (GcmSensor *sensor, GCancellable *cancellable,
  * gcm_sensor_huey_get_ambient_finish:
  **/
 static gboolean
-gcm_sensor_huey_get_ambient_finish (GcmSensor *sensor, GAsyncResult *res, gdouble *value, GError **error)
+gcm_sensor_huey_get_ambient_finish (GcmSensor *sensor,
+				    GAsyncResult *res,
+				    gdouble *value,
+				    GError **error)
 {
 	GSimpleAsyncResult *simple;
 	gboolean ret = TRUE;
@@ -519,8 +590,18 @@ gcm_sensor_huey_set_leds (GcmSensor *sensor, guint8 value, GError **error)
 	guchar reply[8];
 	gsize reply_read;
 	GcmSensorHuey *sensor_huey = GCM_SENSOR_HUEY (sensor);
-	guchar payload[] = { GCM_SENSOR_HUEY_COMMAND_SET_LEDS, 0x00, ~value, 0x00, 0x00, 0x00, 0x00, 0x00 };
-	return gcm_sensor_huey_send_data (sensor_huey, payload, 8, reply, 8, &reply_read, error);
+	guchar payload[] = { GCM_SENSOR_HUEY_COMMAND_SET_LEDS,
+			     0x00,
+			     ~value,
+			     0x00,
+			     0x00,
+			     0x00,
+			     0x00,
+			     0x00 };
+	return gcm_sensor_huey_send_data (sensor_huey,
+					  payload, 8, reply, 8,
+					  &reply_read,
+					  error);
 }
 
 typedef struct {
@@ -529,13 +610,23 @@ typedef struct {
 	guint16	B;
 } GcmSensorHueyMultiplier;
 
+typedef struct {
+	guint32	R;
+	guint32	G;
+	guint32	B;
+} GcmSensorHueyDeviceRaw;
+
 /**
  * gcm_sensor_huey_sample_for_threshold:
  **/
 static gboolean
-gcm_sensor_huey_sample_for_threshold (GcmSensorHuey *sensor_huey, GcmSensorHueyMultiplier *threshold, GcmColorRGB *values, GError **error)
+gcm_sensor_huey_sample_for_threshold (GcmSensorHuey *sensor_huey,
+				      GcmSensorHueyMultiplier *threshold,
+				      GcmSensorHueyDeviceRaw *raw,
+				      GError **error)
 {
-	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_SENSOR_MEASURE_RGB, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
+	guchar request[] = { GCM_SENSOR_HUEY_COMMAND_SENSOR_MEASURE_RGB,
+			     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
 	guchar reply[8];
 	gboolean ret;
 	gsize reply_read;
@@ -546,30 +637,42 @@ gcm_sensor_huey_sample_for_threshold (GcmSensorHuey *sensor_huey, GcmSensorHueyM
 	gcm_buffer_write_uint16_be (request + 5, threshold->B);
 
 	/* measure, and get red */
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 error);
 	if (!ret)
 		goto out;
 
 	/* get value */
-	values->R = (gdouble) threshold->R / (gdouble)gcm_buffer_read_uint16_be (reply+3);
+	raw->R = gcm_buffer_read_uint32_be (reply+2);
 
 	/* get green */
 	request[0] = GCM_SENSOR_HUEY_COMMAND_READ_GREEN;
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 error);
 	if (!ret)
 		goto out;
 
 	/* get value */
-	values->G = (gdouble) threshold->G / (gdouble)gcm_buffer_read_uint16_be (reply+3);
+	raw->G = gcm_buffer_read_uint32_be (reply+2);
 
 	/* get blue */
 	request[0] = GCM_SENSOR_HUEY_COMMAND_READ_BLUE;
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 error);
 	if (!ret)
 		goto out;
 
 	/* get value */
-	values->B = (gdouble) threshold->B / (gdouble)gcm_buffer_read_uint16_be (reply+3);
+	raw->B = gcm_buffer_read_uint32_be (reply+2);
 out:
 	return ret;
 }
@@ -577,53 +680,49 @@ out:
 /**
  * gcm_sensor_huey_convert_device_RGB_to_XYZ:
  *
- * / X \   (( / R \             )   / d \    / c a l \ )
- * | Y | = (( | G | x pre-scale ) - | r |  * | m a t | ) x post_scale
- * \ Z /   (( \ B /             )   \ k /    \ l c d / )
+ * / X \   ( / R \    / c a l \ )
+ * | Y | = ( | G |  * | m a t | ) x post_scale
+ * \ Z /   ( \ B /    \ l c d / )
  *
- * The device RGB values have to be scaled to something in the same
- * scale as the dark calibration. The results then have to be scaled
- * after convolving. I assume the first is a standard value, and the
- * second scale must be available in the eeprom somewhere.
+ * FIXME: I assume the post_scale is in the eeprom somewhere.
  **/
 static void
-gcm_sensor_huey_convert_device_RGB_to_XYZ (GcmColorRGB *src, GcmColorXYZ *dest,
-					   GcmMat3x3 *calibration, GcmVec3 *dark_offset,
-					   gdouble pre_scale, gdouble post_scale)
+gcm_sensor_huey_convert_device_RGB_to_XYZ (GcmColorRGB *src,
+					   GcmColorXYZ *dest,
+					   GcmMat3x3 *calibration,
+					   gdouble post_scale)
 {
-	GcmVec3 *color_native_vec3;
 	GcmVec3 *color_result_vec3;
-	GcmVec3 temp;
-
-	/* pre-multiply */
-	color_native_vec3 = gcm_color_get_RGB_Vec3 (src);
-	gcm_vec3_scalar_multiply (color_native_vec3, pre_scale, &temp);
-
-	/* remove dark calibration */
-	gcm_vec3_subtract (&temp, dark_offset, &temp);
+	GcmVec3 *temp;
 
 	/* convolve */
+	temp = gcm_color_get_RGB_Vec3 (src);
 	color_result_vec3 = gcm_color_get_XYZ_Vec3 (dest);
-	gcm_mat33_vector_multiply (calibration, &temp, color_result_vec3);
+	gcm_mat33_vector_multiply (calibration, temp, color_result_vec3);
 
 	/* post-multiply */
-	gcm_vec3_scalar_multiply (color_result_vec3, post_scale, color_result_vec3);
+	gcm_vec3_scalar_multiply (color_result_vec3,
+				  post_scale,
+				  color_result_vec3);
 }
 
 static void
-gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res, GObject *object, GCancellable *cancellable)
+gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res,
+				  GObject *object,
+				  GCancellable *cancellable)
 {
-	GcmSensor *sensor = GCM_SENSOR (object);
-	GError *error = NULL;
 	gboolean ret = FALSE;
-	gdouble precision_value;
-	GcmColorRGB color_native;
+	GcmColorRGB values;
 	GcmColorXYZ color_result;
 	GcmColorXYZ *tmp;
-	GcmSensorHueyMultiplier multiplier;
-	GcmSensorHuey *sensor_huey = GCM_SENSOR_HUEY (sensor);
 	GcmMat3x3 *device_calibration;
+	GcmSensorHueyDeviceRaw color_native;
+	GcmSensorHueyMultiplier multiplier;
 	GcmSensorOutputType output_type;
+	GcmVec3 *temp;
+	GError *error = NULL;
+	GcmSensor *sensor = GCM_SENSOR (object);
+	GcmSensorHuey *sensor_huey = GCM_SENSOR_HUEY (sensor);
 
 	/* ensure sensor is started */
 	if (!sensor_huey->priv->done_startup) {
@@ -640,7 +739,7 @@ gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res, GObject *object, GCan
 	if (output_type == GCM_SENSOR_OUTPUT_TYPE_PROJECTOR) {
 		g_set_error_literal (&error, GCM_SENSOR_ERROR,
 				     GCM_SENSOR_ERROR_NO_SUPPORT,
-				     "HUEY cannot measure ambient light in projector mode");
+				     "HUEY cannot measure in projector mode");
 		g_simple_async_result_set_from_error (res, error);
 		g_error_free (error);
 		goto out;
@@ -653,19 +752,22 @@ gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res, GObject *object, GCan
 	multiplier.R = 1;
 	multiplier.G = 1;
 	multiplier.B = 1;
-	ret = gcm_sensor_huey_sample_for_threshold (sensor_huey, &multiplier, &color_native, &error);
+	ret = gcm_sensor_huey_sample_for_threshold (sensor_huey,
+						    &multiplier,
+						    &color_native,
+						    &error);
 	if (!ret) {
 		g_simple_async_result_set_from_error (res, error);
 		g_error_free (error);
 		goto out;
 	}
-	g_debug ("initial values: red=%0.6lf, green=%0.6lf, blue=%0.6lf", color_native.R, color_native.G, color_native.B);
+	g_debug ("initial values: red=%i, green=%i, blue=%i",
+		 color_native.R, color_native.G, color_native.B);
 
-	/* compromise between the amount of time and the precision */
-	precision_value = (gdouble) HUEY_PRECISION_TIME_VALUE;
-	multiplier.R = precision_value * color_native.R;
-	multiplier.G = precision_value * color_native.G;
-	multiplier.B = precision_value * color_native.B;
+	/* try to fill the 16 bit register for accuracy */
+	multiplier.R = HUEY_POLL_FREQUENCY / color_native.R;
+	multiplier.G = HUEY_POLL_FREQUENCY / color_native.G;
+	multiplier.B = HUEY_POLL_FREQUENCY / color_native.B;
 
 	/* don't allow a value of zero */
 	if (multiplier.R == 0)
@@ -674,15 +776,45 @@ gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res, GObject *object, GCan
 		multiplier.G = 1;
 	if (multiplier.B == 0)
 		multiplier.B = 1;
-	g_debug ("using multiplier factor: red=%i, green=%i, blue=%i", multiplier.R, multiplier.G, multiplier.B);
-	ret = gcm_sensor_huey_sample_for_threshold (sensor_huey, &multiplier, &color_native, &error);
+	g_debug ("using multiplier factor: red=%i, green=%i, blue=%i",
+		 multiplier.R, multiplier.G, multiplier.B);
+	ret = gcm_sensor_huey_sample_for_threshold (sensor_huey,
+						    &multiplier,
+						    &color_native,
+						    &error);
 	if (!ret) {
 		g_simple_async_result_set_from_error (res, error);
 		g_error_free (error);
 		goto out;
 	}
 
-	g_debug ("scaled values: red=%0.6lf, green=%0.6lf, blue=%0.6lf", color_native.R, color_native.G, color_native.B);
+	g_debug ("raw values: red=%i, green=%i, blue=%i",
+		 color_native.R, color_native.G, color_native.B);
+
+	/* get DeviceRGB values */
+	values.R = (gdouble) multiplier.R * 0.5f * HUEY_POLL_FREQUENCY / ((gdouble) color_native.R);
+	values.G = (gdouble) multiplier.G * 0.5f * HUEY_POLL_FREQUENCY / ((gdouble) color_native.G);
+	values.B = (gdouble) multiplier.B * 0.5f * HUEY_POLL_FREQUENCY / ((gdouble) color_native.B);
+
+	g_debug ("scaled values: red=%0.6lf, green=%0.6lf, blue=%0.6lf",
+		 values.R, values.G, values.B);
+
+	/* remove dark offset */
+	temp = gcm_color_get_RGB_Vec3 (&values);
+	gcm_vec3_subtract (temp,
+			   &sensor_huey->priv->dark_offset,
+			   temp);
+
+	g_debug ("dark offset values: red=%0.6lf, green=%0.6lf, blue=%0.6lf",
+		 values.R, values.G, values.B);
+
+	/* negative values don't make sense (device needs recalibration) */
+	if (values.R < 0.0f)
+		values.R = 0.0f;
+	if (values.G < 0.0f)
+		values.G = 0.0f;
+	if (values.B < 0.0f)
+		values.B = 0.0f;
 
 	/* we use different calibration matrices for each output type */
 	if (output_type == GCM_SENSOR_OUTPUT_TYPE_LCD) {
@@ -694,14 +826,13 @@ gcm_sensor_huey_sample_thread_cb (GSimpleAsyncResult *res, GObject *object, GCan
 	}
 
 	/* convert from device RGB to XYZ */
-	gcm_sensor_huey_convert_device_RGB_to_XYZ (&color_native,
+	gcm_sensor_huey_convert_device_RGB_to_XYZ (&values,
 						   &color_result,
 						   device_calibration,
-						   &sensor_huey->priv->dark_offset,
-						   2000.0f,
 						   HUEY_XYZ_POST_MULTIPLY_SCALE_FACTOR);
 
-	g_debug ("finished values: red=%0.6lf, green=%0.6lf, blue=%0.6lf", color_result.X, color_result.Y, color_result.Z);
+	g_debug ("finished values: red=%0.6lf, green=%0.6lf, blue=%0.6lf",
+		 color_result.X, color_result.Y, color_result.Z);
 
 	/* save result */
 	tmp = g_new0 (GcmColorXYZ, 1);
@@ -716,7 +847,9 @@ out:
  * gcm_sensor_huey_sample_async:
  **/
 static void
-gcm_sensor_huey_sample_async (GcmSensor *sensor, GCancellable *cancellable, GAsyncResult *res)
+gcm_sensor_huey_sample_async (GcmSensor *sensor,
+			      GCancellable *cancellable,
+			      GAsyncResult *res)
 {
 	GcmSensorAsyncState *state;
 
@@ -740,7 +873,10 @@ gcm_sensor_huey_sample_async (GcmSensor *sensor, GCancellable *cancellable, GAsy
  * gcm_sensor_huey_sample_finish:
  **/
 static gboolean
-gcm_sensor_huey_sample_finish (GcmSensor *sensor, GAsyncResult *res, GcmColorXYZ *value, GError **error)
+gcm_sensor_huey_sample_finish (GcmSensor *sensor,
+			       GAsyncResult *res,
+			       GcmColorXYZ *value,
+			       GError **error)
 {
 	GSimpleAsyncResult *simple;
 	gboolean ret = TRUE;
@@ -784,7 +920,11 @@ gcm_sensor_huey_send_unlock (GcmSensorHuey *sensor_huey, GError **error)
 	request[7] = 'd'; /* <-         "" */
 
 	/* no idea why the hardware gets 'locked' */
-	ret = gcm_sensor_huey_send_data (sensor_huey, request, 8, reply, 8, &reply_read, error);
+	ret = gcm_sensor_huey_send_data (sensor_huey,
+					 request, 8,
+					 reply, 8,
+					 &reply_read,
+					 error);
 	if (!ret)
 		goto out;
 out:
@@ -823,7 +963,8 @@ gcm_sensor_huey_startup (GcmSensor *sensor, GError **error)
 	/* get serial number */
 	ret = gcm_sensor_huey_read_register_word (sensor_huey,
 						  GCM_SENSOR_HUEY_EEPROM_ADDR_SERIAL,
-						  &serial_number, error);
+						  &serial_number,
+						  error);
 	if (!ret)
 		goto out;
 	serial_number_tmp = g_strdup_printf ("%i", serial_number);
@@ -833,7 +974,9 @@ gcm_sensor_huey_startup (GcmSensor *sensor, GError **error)
 	/* get unlock string */
 	ret = gcm_sensor_huey_read_register_string (sensor_huey,
 						    GCM_SENSOR_HUEY_EEPROM_ADDR_UNLOCK,
-						    priv->unlock_string, 5, error);
+						    priv->unlock_string,
+						    5,
+						    error);
 	if (!ret)
 		goto out;
 	g_debug ("Unlock string: %s", priv->unlock_string);
@@ -842,31 +985,37 @@ gcm_sensor_huey_startup (GcmSensor *sensor, GError **error)
 	gcm_mat33_clear (&priv->calibration_lcd);
 	ret = gcm_sensor_huey_read_register_matrix (sensor_huey,
 						    GCM_SENSOR_HUEY_EEPROM_ADDR_CALIBRATION_DATA_LCD,
-						    &priv->calibration_lcd, error);
+						    &priv->calibration_lcd,
+						    error);
 	if (!ret)
 		goto out;
-	g_debug ("device matrix1: %s", gcm_mat33_to_string (&priv->calibration_lcd));
+	g_debug ("device calibration LCD: %s",
+		 gcm_mat33_to_string (&priv->calibration_lcd));
 
 	/* get another matrix, although this one is different... */
 	gcm_mat33_clear (&priv->calibration_crt);
 	ret = gcm_sensor_huey_read_register_matrix (sensor_huey,
 						    GCM_SENSOR_HUEY_EEPROM_ADDR_CALIBRATION_DATA_CRT,
-						    &priv->calibration_crt, error);
+						    &priv->calibration_crt,
+						    error);
 	if (!ret)
 		goto out;
-	g_debug ("device matrix2: %s", gcm_mat33_to_string (&priv->calibration_crt));
+	g_debug ("device calibration CRT: %s",
+		 gcm_mat33_to_string (&priv->calibration_crt));
 
 	/* this number is different on all three hueys */
 	ret = gcm_sensor_huey_read_register_float (sensor_huey,
-						   GCM_SENSOR_HUEY_EEPROM_ADDR_CALIB_VALUE,
-						   &priv->calibration_value, error);
+						   GCM_SENSOR_HUEY_EEPROM_ADDR_AMBIENT_CALIB_VALUE,
+						   &priv->calibration_value,
+						   error);
 	if (!ret)
 		goto out;
 
 	/* this vector changes between sensor 1 and 3 */
 	ret = gcm_sensor_huey_read_register_vector (sensor_huey,
 						    GCM_SENSOR_HUEY_EEPROM_ADDR_DARK_OFFSET,
-						    &priv->dark_offset, error);
+						    &priv->dark_offset,
+						    error);
 	if (!ret)
 		goto out;
 
@@ -908,8 +1057,10 @@ gcm_sensor_huey_dump (GcmSensor *sensor, GString *data, GError **error)
 
 	/* dump the unlock string */
 	g_string_append_printf (data, "huey-dump-version:%i\n", 2);
-	g_string_append_printf (data, "unlock-string:%s\n", priv->unlock_string);
-	g_string_append_printf (data, "calibration-value:%f\n", priv->calibration_value);
+	g_string_append_printf (data, "unlock-string:%s\n",
+				priv->unlock_string);
+	g_string_append_printf (data, "calibration-value:%f\n",
+				priv->calibration_value);
 	g_string_append_printf (data, "dark-offset:%f,%f,%f\n",
 				priv->dark_offset.v0,
 				priv->dark_offset.v1,
@@ -917,11 +1068,18 @@ gcm_sensor_huey_dump (GcmSensor *sensor, GString *data, GError **error)
 
 	/* read all the register space */
 	for (i=0; i<0xff; i++) {
-		ret = gcm_sensor_huey_read_register_byte (sensor_huey, i, &value, error);
+		ret = gcm_sensor_huey_read_register_byte (sensor_huey,
+							  i,
+							  &value,
+							  error);
 		if (!ret)
 			goto out;
+
 		/* write details */
-		g_string_append_printf (data, "register[0x%02x]:0x%02x\n", i, value);
+		g_string_append_printf (data,
+					"register[0x%02x]:0x%02x\n",
+					i,
+					value);
 	}
 out:
 	return ret;
