@@ -36,8 +36,6 @@
 #include "gcm-x11-output.h"
 #include "gcm-x11-screen.h"
 
-#include "egg-debug.h"
-
 static void     gcm_device_xrandr_finalize	(GObject     *object);
 
 #define GCM_DEVICE_XRANDR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_DEVICE_XRANDR, GcmDeviceXrandrPrivate))
@@ -256,7 +254,7 @@ gcm_device_xrandr_set_from_output (GcmDevice *device, GcmX11Output *output, GErr
 
 	/* get details */
 	id = gcm_device_xrandr_get_id_for_xrandr_device (GCM_DEVICE_XRANDR(device), output);
-	egg_debug ("asking to add %s", id);
+	g_debug ("asking to add %s", id);
 
 	/* get data about the display */
 	model = gcm_edid_get_monitor_name (priv->edid);
@@ -299,7 +297,7 @@ out:
 }
 
 /**
- * gcm_device_xrandr_apply_for_output:
+ * gcm_device_xrandr_get_xrandr13:
  * @device_xrandr: a valid #GcmDeviceXrandr instance
  *
  * Return value: %TRUE if the display supports XRandr 1.3;
@@ -389,6 +387,76 @@ gcm_device_xrandr_get_config_data (GcmDevice *device)
 	return g_strdup_printf ("edid-hash=%s", priv->edid_md5);
 }
 
+/**
+ * gcm_device_xrandr_generate_profile:
+ **/
+static GcmProfile *
+gcm_device_xrandr_generate_profile (GcmDevice *device, GError **error)
+{
+	gboolean ret;
+	const gchar *data;
+	gchar *title = NULL;
+	GcmProfile *profile;
+	GcmDeviceXrandr *device_xrandr = GCM_DEVICE_XRANDR (device);
+	GcmDeviceXrandrPrivate *priv = device_xrandr->priv;
+
+	/* create new profile */
+	profile = gcm_profile_new ();
+	gcm_profile_set_colorspace (profile, 0);
+	gcm_profile_set_copyright (profile, "No copyright");
+	gcm_profile_set_kind (profile, GCM_PROFILE_KIND_DISPLAY_DEVICE);
+
+	/* get manufacturer */
+	data = gcm_edid_get_vendor_name (priv->edid);
+	if (data == NULL)
+		data = "Unknown vendor";
+	gcm_profile_set_manufacturer (profile, data);
+
+	/* get model */
+	data = gcm_edid_get_monitor_name (priv->edid);
+	if (data == NULL)
+		data = "Unknown monitor";
+	gcm_profile_set_model (profile, data);
+
+	/* TRANSLATORS: this is prepended to the device title to let the use know it was generated by us automatically */
+	title = g_strdup_printf ("%s, %s", _("Automatic"), gcm_device_get_title (device));
+	gcm_profile_set_description (profile, title);
+
+	/* generate a profile from the chroma data */
+	ret = gcm_profile_create_from_chroma (profile,
+					      gcm_edid_get_gamma (priv->edid),
+					      gcm_edid_get_red (priv->edid),
+					      gcm_edid_get_green (priv->edid),
+					      gcm_edid_get_blue (priv->edid),
+					      gcm_edid_get_white (priv->edid),
+					      error);
+	if (!ret) {
+		g_object_unref (profile);
+		profile = NULL;
+		goto out;
+	}
+
+	/* set 'ICC meta Tag for Monitor Profiles' data */
+	gcm_profile_set_data (profile,
+			      "EDID_md5",
+			      gcm_edid_get_checksum (priv->edid));
+	gcm_profile_set_data (profile,
+			      "EDID_model",
+			      gcm_edid_get_monitor_name (priv->edid));
+	gcm_profile_set_data (profile,
+			      "EDID_serial",
+			      gcm_edid_get_serial_number (priv->edid));
+	gcm_profile_set_data (profile,
+			      "EDID_mnft",
+			      gcm_edid_get_pnp_id (priv->edid));
+	gcm_profile_set_data (profile,
+			      "EDID_manufacturer",
+			      gcm_edid_get_vendor_name (priv->edid));
+out:
+	g_free (title);
+	return profile;
+}
+
 /**
  * gcm_device_xrandr_is_primary:
  *
@@ -414,6 +482,60 @@ out:
 	return ret;
 }
 
+/**
+ * gcm_device_xrandr_reset:
+ *
+ * Clears any VCGT table, so we're ready for profiling
+ *
+ * Return value: %TRUE for success;
+ **/
+gboolean
+gcm_device_xrandr_reset (GcmDeviceXrandr *device_xrandr, GError **error)
+{
+	const gchar *id;
+	const gchar *output_name;
+	gboolean ret = FALSE;
+	GcmClut *clut = NULL;
+	GcmDeviceKind kind;
+	GcmX11Output *output;
+	guint size;
+	GcmDeviceXrandrPrivate *priv = device_xrandr->priv;
+
+	/* do no set the gamma for non-display types */
+	id = gcm_device_get_id (GCM_DEVICE (device_xrandr));
+	kind = gcm_device_get_kind (GCM_DEVICE (device_xrandr));
+	if (kind != GCM_DEVICE_KIND_DISPLAY) {
+		g_set_error (error, 1, 0, "not a display: %s", id);
+		goto out;
+	}
+
+	/* should be set for display types */
+	output_name = gcm_device_xrandr_get_native_device (device_xrandr);
+	if (output_name == NULL || output_name[0] == '\0') {
+		g_set_error (error, 1, 0, "no output name for display: %s", id);
+		goto out;
+	}
+
+	/* get GcmX11Output for this device */
+	output = gcm_x11_screen_get_output_by_name (priv->screen, output_name, error);
+	if (output == NULL)
+		goto out;
+	size = gcm_x11_output_get_gamma_size (output);
+
+	/* create a linear ramp */
+	clut = gcm_clut_new ();
+	g_object_set (clut,
+		      "size", size,
+		      NULL);
+
+	/* actually set the gamma */
+	ret = gcm_device_xrandr_apply_for_output (device_xrandr, output, clut, error);
+	if (!ret)
+		goto out;
+out:
+	return ret;
+}
+
 /**
  * gcm_device_xrandr_apply:
  *
@@ -468,7 +590,7 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		filename_systemwide = g_strdup_printf ("%s/icc/%s.icc", GCM_SYSTEM_PROFILES_DIR, id);
 		ret = g_file_test (filename_systemwide, G_FILE_TEST_EXISTS);
 		if (ret) {
-			egg_debug ("using systemwide %s as profile", filename_systemwide);
+			g_debug ("using systemwide %s as profile", filename_systemwide);
 			profile = gcm_profile_new ();
 			file = g_file_new_for_path (filename_systemwide);
 			ret = gcm_profile_parse (profile, file, error);
@@ -544,6 +666,11 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 	} else {
 		/* set the per-output and per screen profile atoms */
 		filename = gcm_profile_get_filename (profile);
+		if (filename == NULL) {
+			ret = FALSE;
+			g_set_error_literal (error, 1, 0, "no filename for profile");
+			goto out;
+		}
 		ret = gcm_x11_output_set_profile (output, filename, error);
 		if (!ret)
 			goto out;
@@ -631,6 +758,7 @@ gcm_device_xrandr_class_init (GcmDeviceXrandrClass *klass)
 
 	device_class->apply = gcm_device_xrandr_apply;
 	device_class->get_config_data = gcm_device_xrandr_get_config_data;
+	device_class->generate_profile = gcm_device_xrandr_generate_profile;
 
 	/**
 	 * GcmDeviceXrandr:native-device:
